@@ -1,7 +1,7 @@
 package Media::Info::Ffmpeg;
 
-our $DATE = '2016-04-06'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-06-09'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use Capture::Tiny qw(capture);
-use Log::Any::For::Builtins qw(system);
+use IPC::System::Options 'system', -log=>1;
 use Perinci::Sub::Util qw(err);
 
 require Exporter;
@@ -96,7 +96,7 @@ Media::Info::Ffmpeg - Return information on media file/URL, using ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.002 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2016-04-06.
+This document describes version 0.003 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2016-06-09.
 
 =head1 SYNOPSIS
 
